==> ViennaRNA-2.4.2.tar.gz: ViennaRNA-2.4.2/doc/html/unstructured__domains_8h.js <==
var unstructured__domains_8h =
[
    [ "vrna_unstructured_domain_motif_s", "structvrna__unstructured__domain__motif__s.html", null ],
    [ "VRNA_UNSTRUCTURED_DOMAIN_EXT_LOOP", "group__domains__up.html#gaac911374e86236a51bfd42e1f098eaba", null ],
    [ "VRNA_UNSTRUCTURED_DOMAIN_HP_LOOP", "group__domains__up.html#ga23b610ea9564346c45cc1e2bbb62adf7", null ],
    [ "VRNA_UNSTRUCTURED_DOMAIN_INT_LOOP", "group__domains__up.html#gac4a0feccd9654c149203200248c2716b", null ],
    [ "VRNA_UNSTRUCTURED_DOMAIN_MB_LOOP", "group__domains__up.html#ga67b80796655e5227a4ed662bfbe398b0", null ],
    [ "VRNA_UNSTRUCTURED_DOMAIN_MOTIF", "group__domains__up.html#gaab12b58d59be76446a9f76fad2fe624c", null ],
    [ "VRNA_UNSTRUCTURED_DOMAIN_ALL_LOOPS", "group__domains__up.html#ga3c6be4cce70f1af9e885788856101699", null ],
    [ "vrna_ud_t", "group__domains__up.html#ga0009117b14d29143e8b18ab891f48c2d", null ],
    [ "vrna_callback_ud_energy", "group__domains__up.html#ga75825c57d0bfde4ae4f95c044260c5c3", null ],
    [ "vrna_callback_ud_exp_energy", "group__domains__up.html#ga861706f257ba993753464b823e65b86e", null ],
    [ "vrna_callback_ud_production", "group__domains__up.html#ga4fdfc02c1b660c07f2d887772f02a0a1", null ],
    [ "vrna_callback_ud_exp_production", "group__domains__up.html#ga33d78327dcd04c1ca5ab2887edc18c7b", null ],
    [ "vrna_callback_ud_probs_add", "group__domains__up.html#gab10498abc84fcaf336aca8f8d7d42eb2", null ],
    [ "vrna_callback_ud_probs_get", "group__domains__up.html#gaa10ba1b6f1e179ea84c5caca9cdaae67", null ],
    [ "vrna_ud_add_motif", "group__domains__up.html#gaec0c3313fb2951946614f920d289829a", null ],
    [ "vrna_ud_get_motif_size_at", "unstructured__domains_8h.html#aea51485feeafed1f93222ba7db9fc3b1", null ],
    [ "vrna_ud_remove", "group__domains__up.html#gada59cb0c498b812eadd010811af3f2d4", null ],
    [ "vrna_ud_set_data", "group__domains__up.html#gac1f18c312b91d80089534a87d956e58b", null ],
    [ "vrna_ud_set_prod_rule_cb", "group__domains__up.html#ga745a99f0bc72898d54de16f6e538828a", null ],
    [ "vrna_ud_set_exp_prod_rule_cb", "group__domains__up.html#ga2fb1db2099da26c76247e1209ad4aa09", null ],
    [ "vrna_ud_set_prob_cb", "unstructured__domains_8h.html#a13ac877c9db89a1a5b5d9c0394148595", null ]
];

==> ViennaRNA-2.4.15.tar.gz: ViennaRNA-2.4.15/doc/html/unstructured__domains_8h.js <==
var unstructured__domains_8h =
[
    [ "vrna_unstructured_domain_motif_s", "structvrna__unstructured__domain__motif__s.html", null ],
    [ "VRNA_UNSTRUCTURED_DOMAIN_EXT_LOOP", "group__domains__up.html#gaac911374e86236a51bfd42e1f098eaba", null ],
    [ "VRNA_UNSTRUCTURED_DOMAIN_HP_LOOP", "group__domains__up.html#ga23b610ea9564346c45cc1e2bbb62adf7", null ],
    [ "VRNA_UNSTRUCTURED_DOMAIN_INT_LOOP", "group__domains__up.html#gac4a0feccd9654c149203200248c2716b", null ],
    [ "VRNA_UNSTRUCTURED_DOMAIN_MB_LOOP", "group__domains__up.html#ga67b80796655e5227a4ed662bfbe398b0", null ],
    [ "VRNA_UNSTRUCTURED_DOMAIN_MOTIF", "group__domains__up.html#gaab12b58d59be76446a9f76fad2fe624c", null ],
    [ "VRNA_UNSTRUCTURED_DOMAIN_ALL_LOOPS", "group__domains__up.html#ga3c6be4cce70f1af9e885788856101699", null ],
    [ "vrna_ud_t", "group__domains__up.html#ga0009117b14d29143e8b18ab891f48c2d", null ],
    [ "vrna_callback_ud_energy", "group__domains__up.html#ga75825c57d0bfde4ae4f95c044260c5c3", null ],
    [ "vrna_callback_ud_exp_energy", "group__domains__up.html#ga861706f257ba993753464b823e65b86e", null ],
    [ "vrna_callback_ud_production", "group__domains__up.html#ga4fdfc02c1b660c07f2d887772f02a0a1", null ],
    [ "vrna_callback_ud_exp_production", "group__domains__up.html#ga33d78327dcd04c1ca5ab2887edc18c7b", null ],
    [ "vrna_callback_ud_probs_add", "group__domains__up.html#gab10498abc84fcaf336aca8f8d7d42eb2", null ],
    [ "vrna_callback_ud_probs_get", "group__domains__up.html#gaa10ba1b6f1e179ea84c5caca9cdaae67", null ],
    [ "vrna_ud_motifs_centroid", "group__domains__up.html#ga2039caedf194c5edec794866986d95ec", null ],
    [ "vrna_ud_motifs_MEA", "group__domains__up.html#ga980126e9f350b64474b35f20fce2782c", null ],
    [ "vrna_ud_motifs_MFE", "group__domains__up.html#ga464d086264dd6f45089a65acec4e8c21", null ],
    [ "vrna_ud_add_motif", "group__domains__up.html#ga55f7de5ef5b7472b0eeab9296b57f671", null ],
    [ "vrna_ud_get_motif_size_at", "unstructured__domains_8h.html#aea51485feeafed1f93222ba7db9fc3b1", null ],
    [ "vrna_ud_remove", "group__domains__up.html#gada59cb0c498b812eadd010811af3f2d4", null ],
    [ "vrna_ud_set_data", "group__domains__up.html#gac1f18c312b91d80089534a87d956e58b", null ],
    [ "vrna_ud_set_prod_rule_cb", "group__domains__up.html#ga745a99f0bc72898d54de16f6e538828a", null ],
    [ "vrna_ud_set_exp_prod_rule_cb", "group__domains__up.html#ga2fb1db2099da26c76247e1209ad4aa09", null ],
    [ "vrna_ud_set_prob_cb", "unstructured__domains_8h.html#a13ac877c9db89a1a5b5d9c0394148595", null ]
];
